Re-brand setup.py
authorStefano Rivera <stefano@rivera.za.net>
Sat, 17 May 2014 09:41:32 +0000 (11:41 +0200)
committerStefano Rivera <stefano@rivera.za.net>
Sat, 17 May 2014 09:42:13 +0000 (11:42 +0200)
setup.py

index e8042f9e8b1d5ae967bed2da00bbeda10a72a98c..792f01e560ddfb97eaca0c4441894a1c0e043876 100644 (file)
--- a/setup.py
+++ b/setup.py
@@ -2,7 +2,7 @@
 # -*- coding: utf8 -*-
 # vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
 
"""Setuptools setup.py file for naja."""
 
 from setuptools import setup, find_packages
 
@@ -16,9 +16,9 @@ except ImportError:
 VERSION_STR = "0.1"
 
 setup(
-    name="naja",
+    name="robolock-II",
     version=VERSION_STR,
-    description="naja: Game for PyWeek 18",
+    description="Robolock II - a puzzle game",
 
     author=(", ".join([
         "Simon Cross",
@@ -30,10 +30,10 @@ setup(
     ])),
     author_email="ctpug@googlegroups.com",
 
-    maintainer="Naja Team",
+    maintainer="Team Naja (CTPUG)",
     maintainer_email="ctpug@googlegroups.com",
 
-    url="http://ctpug.org.za/",
+    url="http://robolock.org/",
     download_url="http://ctpug.org.za/git/naja",
 
     license="MIT",
@@ -2,7 +2,7 @@
 # vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
 
-"""Setuptools setup.py file for naja."""
+"""Setuptools setup.py file for Robolock II."""
 
 from setuptools import setup, find_packages